@@ -1,3 +1,4 @@
+"""Gateway API handlers."""
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 import asyncio
@@ -5,6 +6,7 @@ import logging
 import mimetypes
 import os
 import random
+from typing import Optional, cast
 
 from jupyter_client.session import Session
 from tornado import web
@@ -24,6 +26,7 @@ GATEWAY_WS_PING_INTERVAL_SECS = int(os.getenv("GATEWAY_WS_PING_INTERVAL_SECS", 3
 
 
 class WebSocketChannelsHandler(WebSocketHandler, JupyterHandler):
+    """Gateway web socket channels handler."""
 
     session = None
     gateway = None
@@ -31,6 +34,7 @@ class WebSocketChannelsHandler(WebSocketHandler, JupyterHandler):
     ping_callback = None
 
     def check_origin(self, origin=None):
+        """Check origin for the socket."""
         return JupyterHandler.check_origin(self, origin)
 
     def set_default_headers(self):
@@ -38,6 +42,7 @@ class WebSocketChannelsHandler(WebSocketHandler, JupyterHandler):
         pass
 
     def get_compression_options(self):
+        """Get the compression options for the socket."""
         # use deflate compress websocket
         return {}
 
@@ -48,26 +53,31 @@ class WebSocketChannelsHandler(WebSocketHandler, JupyterHandler):
         the websocket finishes completing.
         """
         # authenticate the request before opening the websocket
-        if self.get_current_user() is None:
+        if self.current_user is None:
             self.log.warning("Couldn't authenticate WebSocket connection")
             raise web.HTTPError(403)
 
-        if self.get_argument("session_id", False):
+        if self.get_argument("session_id", None):
+            assert self.session is not None
             self.session.session = self.get_argument("session_id")
         else:
             self.log.warning("No session ID specified")
 
     def initialize(self):
+        """Intialize the socket."""
         self.log.debug("Initializing websocket connection %s", self.request.path)
         self.session = Session(config=self.config)
         self.gateway = GatewayWebSocketClient(gateway_url=GatewayClient.instance().url)
 
     async def get(self, kernel_id, *args, **kwargs):
+        """Get the socket."""
         self.authenticate()
         self.kernel_id = kernel_id
-        await super().get(kernel_id=kernel_id, *args, **kwargs)
+        kwargs["kernel_id"] = kernel_id
+        await super().get(*args, **kwargs)
 
     def send_ping(self):
+        """Send a ping to the socket."""
         if self.ws_connection is None and self.ping_callback is not None:
             self.ping_callback.stop()
             return
@@ -79,6 +89,7 @@ class WebSocketChannelsHandler(WebSocketHandler, JupyterHandler):
         self.ping_callback = PeriodicCallback(self.send_ping, GATEWAY_WS_PING_INTERVAL_SECS * 1000)
         self.ping_callback.start()
 
+        assert self.gateway is not None
         self.gateway.on_open(
             kernel_id=kernel_id,
             message_callback=self.write_message,
@@ -87,6 +98,7 @@ class WebSocketChannelsHandler(WebSocketHandler, JupyterHandler):
 
     def on_message(self, message):
         """Forward message to gateway web socket handler."""
+        assert self.gateway is not None
         self.gateway.on_message(message)
 
     def write_message(self, message, binary=False):
@@ -104,12 +116,15 @@ class WebSocketChannelsHandler(WebSocketHandler, JupyterHandler):
             )
 
     def on_close(self):
+        """Handle a closing socket."""
         self.log.debug("Closing websocket connection %s", self.request.path)
+        assert self.gateway is not None
         self.gateway.on_close()
         super().on_close()
 
     @staticmethod
     def _get_message_summary(message):
+        """Get a summary of a message."""
         summary = []
         message_type = message["msg_type"]
         summary.append(f"type: {message_type}")
@@ -134,14 +149,16 @@ class GatewayWebSocketClient(LoggingConfigurable):
     """Proxy web socket connection to a kernel/enterprise gateway."""
 
     def __init__(self, **kwargs):
-        super().__init__(**kwargs)
+        """Initialize the gateway web socket client."""
+        super().__init__()
         self.kernel_id = None
         self.ws = None
-        self.ws_future = Future()
+        self.ws_future: Future = Future()
         self.disconnected = False
         self.retry = 0
 
     async def _connect(self, kernel_id, message_callback):
+        """Connect to the socket."""
         # websocket is initialized before connection
         self.ws = None
         self.kernel_id = kernel_id
@@ -152,17 +169,18 @@ class GatewayWebSocketClient(LoggingConfigurable):
             "channels",
         )
         self.log.info(f"Connecting to {ws_url}")
-        kwargs = {}
+        kwargs: dict = {}
         kwargs = GatewayClient.instance().load_connection_args(**kwargs)
 
         request = HTTPRequest(ws_url, **kwargs)
-        self.ws_future = websocket_connect(request)
+        self.ws_future = cast(Future, websocket_connect(request))
         self.ws_future.add_done_callback(self._connection_done)
 
         loop = IOLoop.current()
         loop.add_future(self.ws_future, lambda future: self._read_messages(message_callback))
 
     def _connection_done(self, fut):
+        """Handle a finished connection."""
         if (
             not self.disconnected and fut.exception() is None
         ):  # prevent concurrent.futures._base.CancelledError
@@ -178,6 +196,7 @@ class GatewayWebSocketClient(LoggingConfigurable):
             )
 
     def _disconnect(self):
+        """Handle a disconnect."""
         self.disconnected = True
         if self.ws is not None:
             # Close connection
@@ -261,6 +280,8 @@ class GatewayResourceHandler(APIHandler):
 
     @web.authenticated
     async def get(self, kernel_name, path, include_body=True):
+        """Get a gateway resource by name and path."""
+        mimetype: Optional[str] = None
         ksm = self.kernel_spec_manager
         kernel_spec_res = await ksm.get_kernel_spec_resource(kernel_name, path)
         if kernel_spec_res is None:
@@ -269,8 +290,8 @@ class GatewayResourceHandler(APIHandler):
                 " resource serving.".format(path, kernel_name)
             )
         else:
-            self.set_header("Content-Type", mimetypes.guess_type(path)[0])
-        self.finish(kernel_spec_res)
+            mimetype = mimetypes.guess_type(path)[0] or "text/plain"
+        self.finish(kernel_spec_res, set_content_type=mimetype)
 
 
 from ..services.kernels.handlers import _kernel_id_regex
